from sallron.enforcer import *
import os
import pytest

# TODO: test discord message in a separate channel

def test_write_pid():
    write_pid('1234')

def test_kill_pid():
    kill_pid(delete_file=True)

def test_pid_cycle():
    write_pid('1234')
    kill_pid(delete_file=True)
    
def test_eternal_runner():
    os.popen('echo "print()" > test_program.py')
    write_pid('1234')
    with pytest.raises(SystemExit) as pytest_wrapped_e:
        eternal_runner(filepath="test_program.py", test=True)
    assert pytest_wrapped_e.type == SystemExit


from sallron.eye import *
from sallron.util import settings
from os import environ

MOCK_CUSTOMER = 'fibracirurgica'
MOCK_INFO_DICT = dict(vtex_interface = dict(app_key=environ.get('VTEX_TEST_APP_KEY'),
app_token=environ.get('VTEX_TEST_APP_TOKEN'),
environment="vtexcommercestable",
account_name="fibracirurgica", 
local_tz="America/Sao_Paulo"))
MOCK_INTERFACE_NAME = 'vtex_interface'
MONGO_TEST_STR = environ.get('MONGO_TEST_CONN_STR')

class MockInterface():
    def __init__(self,app_key,app_token,environment,account_name,local_tz):
        self.mock_interface = account_name

class MockMongo():
    def insert_data(self, collection, db, data):
        self.database = dict(db=dict(collection=dict(data)))

def mock_function(period):
    pass

def test_eye_class_init():
    TheEyeofSauron(MOCK_CUSTOMER,MOCK_INFO_DICT, MockInterface, MOCK_INTERFACE_NAME)

def test_configureye():
    configureye(MOCK_SETTING='Pterodatilo')
    assert settings.MOCK_SETTING == 'Pterodatilo'

def test_fetch_and_store():
    methods = filter(mock_function, ['steffen', 'chris'])
    client = TheEyeofSauron(MOCK_CUSTOMER,MOCK_INFO_DICT, MockInterface, MOCK_INTERFACE_NAME)
    for method in methods:
        client.fetch_and_store(method, 15, MockMongo)

def test_setup_schedulers():
    client = TheEyeofSauron(MOCK_CUSTOMER,MOCK_INFO_DICT, MockInterface, MOCK_INTERFACE_NAME)
    client.setup_schedulers(dict(name='george'), MockMongo)

# def test_ring_ruler():
#     configureye(MONGO_CONN_STR=MONGO_TEST_STR)
#     ring_ruler(MockInterface, MOCK_INTERFACE_NAME, test=True)



def handle_categories(result):
    '''
    This function receives a list of responses from Vtex API with information about products and returns a list of categories for all the products.

    Args: 
        result (list): list of responses.

    Returns:
        categories (list): List of list of categories. 
    '''
    categories = dict()
    
    for r in result:
        if r and isinstance(r[0], dict):
            categories_temp = r[0].get('categories')
            link_temp = r[0].get('link').split("/")[-2].replace("-", " ").title()

            if isinstance(categories_temp, list):

                cat_temp = list()

                if len(categories_temp) > 1:
                    for i, category in enumerate(categories_temp):
                        if category not in categories_temp[i - 1]:
                            cat_temp.append(category)
                else:
                    cat_temp = categories_temp

            elif isinstance(categories_temp, str):
                cat_temp = [categories_temp]
            else:
                cat_temp = ['']

            categories.update({link_temp: cat_temp})
        else:
            categories.update({'No product': ['No Category']})
    
    return categories